==> vue-element-ui-plus-1.0.53.tgz: package/lib/row.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["vue-element-ui-plus"] = factory();
	else
		root["vue-element-ui-plus"] = factory();
})(self, () => {
return /******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	// The require scope
/******/ 	var __webpack_require__ = {};
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": () => (/* binding */ packages_row)
});

;// CONCATENATED MODULE: ./packages/row/src/row.js
/* harmony default export */ const row = ({
  name: 'ElRow',
  componentName: 'ElRow',
  props: {
    tag: {
      type: String,
      "default": 'div'
    },
    gutter: Number,
    type: String,
    justify: {
      type: String,
      "default": 'start'
    },
    align: String
  },
  computed: {
    style: function style() {
      var ret = {};
      if (this.gutter) {
        ret.marginLeft = "-".concat(this.gutter / 2, "px");
        ret.marginRight = ret.marginLeft;
      }
      return ret;
    }
  },
  render: function render(h) {
    return h(this.tag, {
      "class": ['el-row', this.justify !== 'start' ? "is-justify-".concat(this.justify) : '', this.align ? "is-align-".concat(this.align) : '', {
        'el-row--flex': this.type === 'flex'
      }],
      style: this.style
    }, this.$slots["default"]);
  }
});
;// CONCATENATED MODULE: ./packages/row/index.js


/* istanbul ignore next */
row.install = function (Vue) {
  Vue.component(row.name, row);
};
/* harmony default export */ const packages_row = (row);
__webpack_exports__ = __webpack_exports__["default"];
/******/ 	return __webpack_exports__;
/******/ })()
;
});

==> vue-element-ui-plus-1.0.60.tgz: package/lib/row.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define("VueElementUiPlus", [], factory);
	else if(typeof exports === 'object')
		exports["VueElementUiPlus"] = factory();
	else
		root["VueElementUiPlus"] = factory();
})(self, () => {
return /******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	// The require scope
/******/ 	var __webpack_require__ = {};
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "default": () => (/* binding */ packages_row)
});

;// CONCATENATED MODULE: ./packages/row/src/row.js
/* harmony default export */ const row = ({
  name: 'ElRow',
  componentName: 'ElRow',
  props: {
    tag: {
      type: String,
      "default": 'div'
    },
    gutter: Number,
    type: String,
    justify: {
      type: String,
      "default": 'start'
    },
    align: String
  },
  computed: {
    style: function style() {
      var ret = {};
      if (this.gutter) {
        ret.marginLeft = "-".concat(this.gutter / 2, "px");
        ret.marginRight = ret.marginLeft;
      }
      return ret;
    }
  },
  render: function render(h) {
    return h(this.tag, {
      "class": ['el-row', this.justify !== 'start' ? "is-justify-".concat(this.justify) : '', this.align ? "is-align-".concat(this.align) : '', {
        'el-row--flex': this.type === 'flex'
      }],
      style: this.style
    }, this.$slots["default"]);
  }
});
;// CONCATENATED MODULE: ./packages/row/index.js


/* istanbul ignore next */
row.install = function (Vue) {
  Vue.component(row.name, row);
};
/* harmony default export */ const packages_row = (row);
__webpack_exports__ = __webpack_exports__["default"];
/******/ 	return __webpack_exports__;
/******/ })()
;
});
